JiaPuLayout class
Constructors
Properties
- generationLabelOffsetX → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- layerSpacing → double
-
final
- nodeHeight → double
-
final
- nodeSpacing → double
-
final
- nodeWidth → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startX → double
-
final
- startY → double
-
final
Methods
-
calculateCanvasHeight(
JiaPuMember? root, int generation) → double -
calculateCanvasWidth(
JiaPuMember? root) → double -
calculateOffsets(
JiaPuMember member, int generation) → List< double> -
calculateTreeDepth(
JiaPuMember? member) → int -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited